@@ -215,7 +215,7 @@ class CognitoIdpUserPoolAttribute(BaseModel):
                 "Required custom attributes are not supported currently."
             )
         self.required = False
-        self._init_constraints(schema, None)
+        self._init_constraints(schema, None, show_empty_constraints=True)
 
     def _init_standard(self, schema):
         attribute_data_type = schema.get("AttributeDataType", None)
@@ -234,8 +234,7 @@ class CognitoIdpUserPoolAttribute(BaseModel):
         else:
             self.developer_only = False
         self.mutable = schema.get(
-            "Mutable",
-            CognitoIdpUserPoolAttribute.STANDARD_SCHEMA[self.name]["Mutable"],
+            "Mutable", CognitoIdpUserPoolAttribute.STANDARD_SCHEMA[self.name]["Mutable"]
         )
         self.required = schema.get(
             "Required",
@@ -253,7 +252,9 @@ class CognitoIdpUserPoolAttribute(BaseModel):
         )
         self._init_constraints(schema, default_constraints)
 
-    def _init_constraints(self, schema, default_constraints):
+    def _init_constraints(
+        self, schema, default_constraints, show_empty_constraints=False
+    ):
         def numeric_limit(num, constraint_type):
             if not num:
                 return
@@ -268,7 +269,7 @@ class CognitoIdpUserPoolAttribute(BaseModel):
                 )
             return parsed
 
-        self.string_constraints = None
+        self.string_constraints = {} if show_empty_constraints else None
         self.number_constraints = None
 
         if "AttributeDataType" in schema:
@@ -296,6 +297,7 @@ class CognitoIdpUserPoolAttribute(BaseModel):
                         f"user.{self.name}: Max length cannot be less than min length."
                     )
                 self.string_constraints = string_constraints
+                self.number_constraints = None
             elif self.data_type == "Number":
                 number_constraints = schema.get(
                     "NumberAttributeConstraints", default_constraints
@@ -316,6 +318,10 @@ class CognitoIdpUserPoolAttribute(BaseModel):
                         f"user.{self.name}: Max value cannot be less than min value."
                     )
                 self.number_constraints = number_constraints
+                self.string_constraints = None
+            else:
+                self.number_constraints = None
+                self.string_constraints = None
 
     def to_json(self):
         return {
@@ -329,6 +335,36 @@ class CognitoIdpUserPoolAttribute(BaseModel):
         }
 
 
+DEFAULT_USER_POOL_CONFIG = {
+    "Policies": {
+        "PasswordPolicy": {
+            "MinimumLength": 8,
+            "RequireUppercase": True,
+            "RequireLowercase": True,
+            "RequireNumbers": True,
+            "RequireSymbols": True,
+            "TemporaryPasswordValidityDays": 7,
+        }
+    },
+    "AdminCreateUserConfig": {
+        "AllowAdminCreateUserOnly": False,
+        "UnusedAccountValidityDays": 7,
+        "InviteMessageTemplate": {
+            "SMSMessage": "Your username is {username} and temporary password is {####}. ",
+            "EmailMessage": "Your username is {username} and temporary password is {####}. ",
+            "EmailSubject": "Your temporary password",
+        },
+    },
+    "EmailConfiguration": {"EmailSendingAccount": "COGNITO_DEFAULT"},
+    "VerificationMessageTemplate": {
+        "SmsMessage": "Your verification code is {####}. ",
+        "EmailMessage": "Your verification code is {####}. ",
+        "EmailSubject": "Your verification code",
+        "DefaultEmailOption": "CONFIRM_WITH_CODE",
+    },
+}
+
+
 class CognitoIdpUserPool(BaseModel):
     def __init__(self, region, name, extended_config):
         self.region = region
@@ -338,7 +374,24 @@ class CognitoIdpUserPool(BaseModel):
         )
         self.name = name
         self.status = None
-        self.extended_config = extended_config or {}
+
+        self.extended_config = DEFAULT_USER_POOL_CONFIG.copy()
+        self.extended_config.update(extended_config or {})
+
+        message_template = self.extended_config.get("VerificationMessageTemplate")
+        if message_template and "SmsVerificationMessage" not in extended_config:
+            self.extended_config["SmsVerificationMessage"] = message_template.get(
+                "SmsMessage"
+            )
+        if message_template and "EmailVerificationSubject" not in extended_config:
+            self.extended_config["EmailVerificationSubject"] = message_template.get(
+                "EmailSubject"
+            )
+        if message_template and "EmailVerificationMessage" not in extended_config:
+            self.extended_config["EmailVerificationMessage"] = message_template.get(
+                "EmailMessage"
+            )
+
         self.creation_date = datetime.datetime.utcnow()
         self.last_modified_date = datetime.datetime.utcnow()
 
@@ -347,18 +400,19 @@ class CognitoIdpUserPool(BaseModel):
         self.token_mfa_config = None
 
         self.schema_attributes = {}
-        for schema in extended_config.pop("Schema", {}):
+        for schema in self.extended_config.pop("Schema", {}):
             attribute = CognitoIdpUserPoolAttribute(
                 schema["Name"],
                 schema["Name"] not in CognitoIdpUserPoolAttribute.STANDARD_SCHEMA,
                 schema,
             )
             self.schema_attributes[attribute.name] = attribute
-        for (
-            standard_attribute_name,
-            standard_attribute_schema,
-        ) in CognitoIdpUserPoolAttribute.STANDARD_SCHEMA.items():
-            if standard_attribute_name not in self.schema_attributes:
+        # If we do not have custom attributes, use the standard schema
+        if not self.schema_attributes:
+            for (
+                standard_attribute_name,
+                standard_attribute_schema,
+            ) in CognitoIdpUserPoolAttribute.STANDARD_SCHEMA.items():
                 self.schema_attributes[
                     standard_attribute_name
                 ] = CognitoIdpUserPoolAttribute(
@@ -592,6 +646,9 @@ class CognitoIdpIdentityProvider(BaseModel):
         self.creation_date = datetime.datetime.utcnow()
         self.last_modified_date = datetime.datetime.utcnow()
 
+        if "AttributeMapping" not in self.extended_config:
+            self.extended_config["AttributeMapping"] = {"username": "sub"}
+
     def _base_json(self):
         return {
             "ProviderName": self.name,
@@ -1131,7 +1188,7 @@ class CognitoIdpBackend(BaseBackend):
     def _validate_auth_flow(
         self, auth_flow: str, valid_flows: typing.List[AuthFlow]
     ) -> AuthFlow:
-        """ validate auth_flow value and convert auth_flow to enum """
+        """validate auth_flow value and convert auth_flow to enum"""
 
         try:
             auth_flow = AuthFlow[auth_flow]
@@ -1304,11 +1361,11 @@ class CognitoIdpBackend(BaseBackend):
 
     def forgot_password(self, client_id, username):
         """The ForgotPassword operation is partially broken in AWS. If the input is 100% correct it works fine.
-            Otherwise you get semi-random garbage and HTTP 200 OK, for example:
-            - recovery for username which is not registered in any cognito pool
-            - recovery for username belonging to a different user pool than the client id is registered to
-            - phone-based recovery for a user without phone_number / phone_number_verified attributes
-            - same as above, but email / email_verified
+        Otherwise you get semi-random garbage and HTTP 200 OK, for example:
+        - recovery for username which is not registered in any cognito pool
+        - recovery for username belonging to a different user pool than the client id is registered to
+        - phone-based recovery for a user without phone_number / phone_number_verified attributes
+        - same as above, but email / email_verified
         """
         for user_pool in self.user_pools.values():
             if client_id in user_pool.clients:
@@ -1464,7 +1521,7 @@ class CognitoIdpBackend(BaseBackend):
         user_pool.users[user.username] = user
         return user
 
-    def confirm_sign_up(self, client_id, username, confirmation_code):
+    def confirm_sign_up(self, client_id, username):
         user_pool = None
         for p in self.user_pools.values():
             if client_id in p.clients:
@@ -1525,7 +1582,7 @@ class CognitoIdpBackend(BaseBackend):
                 "ChallengeParameters": {
                     "SALT": uuid.uuid4().hex,
                     "SRP_B": uuid.uuid4().hex,
-                    "USERNAME": user.id,
+                    "USERNAME": user.username,
                     "USER_ID_FOR_SRP": user.id,
                     "SECRET_BLOCK": session,
                 },
@@ -1614,10 +1671,13 @@ class CognitoIdpBackend(BaseBackend):
                 self.admin_get_user(user_pool.id, username)
 
                 return {"SecretCode": str(uuid.uuid4())}
-        else:
-            raise NotAuthorizedError(access_token)
 
-    def verify_software_token(self, access_token, user_code):
+        raise NotAuthorizedError(access_token)
+
+    def verify_software_token(self, access_token):
+        """
+        The parameter UserCode has not yet been implemented
+        """
         for user_pool in self.user_pools.values():
             if access_token in user_pool.access_tokens:
                 _, username = user_pool.access_tokens[access_token]
@@ -1626,8 +1686,8 @@ class CognitoIdpBackend(BaseBackend):
                 user.token_verified = True
 
                 return {"Status": "SUCCESS"}
-        else:
-            raise NotAuthorizedError(access_token)
+
+        raise NotAuthorizedError(access_token)
 
     def set_user_mfa_preference(
         self, access_token, software_token_mfa_settings, sms_mfa_settings
@@ -1655,8 +1715,8 @@ class CognitoIdpBackend(BaseBackend):
                     if sms_mfa_settings.get("PreferredMfa"):
                         user.preferred_mfa_setting = "SMS_MFA"
                 return None
-        else:
-            raise NotAuthorizedError(access_token)
+
+        raise NotAuthorizedError(access_token)
 
     def admin_set_user_mfa_preference(
         self, user_pool_id, username, software_token_mfa_settings, sms_mfa_settings
@@ -1693,7 +1753,35 @@ class CognitoIdpBackend(BaseBackend):
         user_pool.add_custom_attributes(custom_attributes)
 
 
+class GlobalCognitoIdpBackend(CognitoIdpBackend):
+    # Some operations are unauthenticated
+    # Without authentication-header, we lose the context of which region the request was send to
+    # This backend will cycle through all backends as a workaround
+
+    def _find_backend_for_clientid(self, client_id):
+        for region, backend in cognitoidp_backends.items():
+            if region == "global":
+                continue
+            for p in backend.user_pools.values():
+                if client_id in p.clients:
+                    return backend
+        return cognitoidp_backends["us-east-1"]
+
+    def sign_up(self, client_id, username, password, attributes):
+        backend = self._find_backend_for_clientid(client_id)
+        return backend.sign_up(client_id, username, password, attributes)
+
+    def initiate_auth(self, client_id, auth_flow, auth_parameters):
+        backend = self._find_backend_for_clientid(client_id)
+        return backend.initiate_auth(client_id, auth_flow, auth_parameters)
+
+    def confirm_sign_up(self, client_id, username):
+        backend = self._find_backend_for_clientid(client_id)
+        return backend.confirm_sign_up(client_id, username)
+
+
 cognitoidp_backends = BackendDict(CognitoIdpBackend, "cognito-idp")
+cognitoidp_backends["global"] = GlobalCognitoIdpBackend("global")
 
 
 # Hack to help moto-server process requests on localhost, where the region isn't
