@@ -516,7 +516,7 @@ class CognitoIdpResponse(BaseResponse):
         client_id = self._get_param("ClientId")
         username = self._get_param("Username")
         password = self._get_param("Password")
-        user = cognitoidp_backends[self.region].sign_up(
+        user = cognitoidp_backends["global"].sign_up(
             client_id=client_id,
             username=username,
             password=password,
@@ -532,9 +532,8 @@ class CognitoIdpResponse(BaseResponse):
     def confirm_sign_up(self):
         client_id = self._get_param("ClientId")
         username = self._get_param("Username")
-        confirmation_code = self._get_param("ConfirmationCode")
-        cognitoidp_backends[self.region].confirm_sign_up(
-            client_id=client_id, username=username, confirmation_code=confirmation_code,
+        cognitoidp_backends["global"].confirm_sign_up(
+            client_id=client_id, username=username
         )
         return ""
 
@@ -543,7 +542,7 @@ class CognitoIdpResponse(BaseResponse):
         auth_flow = self._get_param("AuthFlow")
         auth_parameters = self._get_param("AuthParameters")
 
-        auth_result = cognitoidp_backends[self.region].initiate_auth(
+        auth_result = cognitoidp_backends["global"].initiate_auth(
             client_id, auth_flow, auth_parameters
         )
 
@@ -556,10 +555,7 @@ class CognitoIdpResponse(BaseResponse):
 
     def verify_software_token(self):
         access_token = self._get_param("AccessToken")
-        user_code = self._get_param("UserCode")
-        result = cognitoidp_backends[self.region].verify_software_token(
-            access_token, user_code
-        )
+        result = cognitoidp_backends[self.region].verify_software_token(access_token)
         return json.dumps(result)
 
     def set_user_mfa_preference(self):
@@ -607,5 +603,7 @@ class CognitoIdpJsonWebKeyResponse(BaseResponse):
         ) as f:
             self.json_web_key = f.read()
 
-    def serve_json_web_key(self, request, full_url, headers):
+    def serve_json_web_key(
+        self, request, full_url, headers
+    ):  # pylint: disable=unused-argument
         return 200, {"Content-Type": "application/json"}, self.json_web_key
