@@ -1,8 +1,7 @@
 import uuid
-from moto.core.responses import BaseResponse
 from moto.ec2.models import OWNER_ID
 from moto.ec2.exceptions import FilterNotImplementedError
-from moto.ec2.utils import filters_from_querystring
+from ._base_response import EC2BaseResponse
 
 from xml.etree import ElementTree
 from xml.dom import minidom
@@ -91,7 +90,7 @@ def parse_lists(data):
     return data
 
 
-class LaunchTemplates(BaseResponse):
+class LaunchTemplates(EC2BaseResponse):
     def create_launch_template(self):
         name = self._get_param("LaunchTemplateName")
         version_description = self._get_param("VersionDescription")
@@ -176,8 +175,25 @@ class LaunchTemplates(BaseResponse):
             )
             return pretty_xml(tree)
 
-    # def delete_launch_template(self):
-    #     pass
+    def delete_launch_template(self):
+        name = self._get_param("LaunchTemplateName")
+        tid = self._get_param("LaunchTemplateId")
+
+        if self.is_not_dryrun("DeleteLaunchTemplate"):
+            template = self.ec2_backend.delete_launch_template(name, tid)
+
+            tree = xml_root("DeleteLaunchTemplatesResponse")
+            xml_serialize(
+                tree,
+                "launchTemplate",
+                {
+                    "defaultVersionNumber": template.default_version_number,
+                    "launchTemplateId": template.id,
+                    "launchTemplateName": template.name,
+                },
+            )
+
+            return pretty_xml(tree)
 
     # def delete_launch_template_versions(self):
     #     pass
@@ -195,7 +211,7 @@ class LaunchTemplates(BaseResponse):
         min_version = self._get_int_param("MinVersion")
         max_version = self._get_int_param("MaxVersion")
 
-        filters = filters_from_querystring(self.querystring)
+        filters = self._filters_from_querystring()
         if filters:
             raise FilterNotImplementedError(
                 "all filters", "DescribeLaunchTemplateVersions"
@@ -255,13 +271,13 @@ class LaunchTemplates(BaseResponse):
         max_results = self._get_int_param("MaxResults", 15)
         template_names = self._get_multi_param("LaunchTemplateName")
         template_ids = self._get_multi_param("LaunchTemplateId")
-        filters = filters_from_querystring(self.querystring)
+        filters = self._filters_from_querystring()
 
         if self.is_not_dryrun("DescribeLaunchTemplates"):
             tree = ElementTree.Element("DescribeLaunchTemplatesResponse")
             templates_node = ElementTree.SubElement(tree, "launchTemplates")
 
-            templates = self.ec2_backend.get_launch_templates(
+            templates = self.ec2_backend.describe_launch_templates(
                 template_names=template_names,
                 template_ids=template_ids,
                 filters=filters,
