@@ -1,14 +1,9 @@
-from __future__ import unicode_literals
-
 import json
 
 from moto.core.responses import BaseResponse
 from .models import mediaconnect_backends
 
-try:
-    from urllib import unquote
-except ImportError:
-    from urllib.parse import unquote
+from urllib.parse import unquote
 
 
 class MediaConnectResponse(BaseResponse):
@@ -23,6 +18,9 @@ class MediaConnectResponse(BaseResponse):
         entitlements = self._get_param("entitlements")
         name = self._get_param("name")
         outputs = self._get_param("outputs")
+        for index, output in enumerate(outputs):
+            if output.get("protocol") in ["srt-listener", "zixi-pull"]:
+                output["listenerAddress"] = f"{index}.0.0.0"
         source = self._get_param("source")
         source_failover_config = self._get_param("sourceFailoverConfig")
         sources = self._get_param("sources")
@@ -43,42 +41,40 @@ class MediaConnectResponse(BaseResponse):
         max_results = self._get_int_param("maxResults")
         next_token = self._get_param("nextToken")
         flows, next_token = self.mediaconnect_backend.list_flows(
-            max_results=max_results, next_token=next_token,
+            max_results=max_results, next_token=next_token
         )
         return json.dumps(dict(flows=flows, nextToken=next_token))
 
     def describe_flow(self):
         flow_arn = unquote(self._get_param("flowArn"))
-        flow, messages = self.mediaconnect_backend.describe_flow(flow_arn=flow_arn,)
+        flow, messages = self.mediaconnect_backend.describe_flow(flow_arn=flow_arn)
         return json.dumps(dict(flow=flow, messages=messages))
 
     def delete_flow(self):
         flow_arn = unquote(self._get_param("flowArn"))
-        flow_arn, status = self.mediaconnect_backend.delete_flow(flow_arn=flow_arn,)
+        flow_arn, status = self.mediaconnect_backend.delete_flow(flow_arn=flow_arn)
         return json.dumps(dict(flowArn=flow_arn, status=status))
 
     def start_flow(self):
         flow_arn = unquote(self._get_param("flowArn"))
-        flow_arn, status = self.mediaconnect_backend.start_flow(flow_arn=flow_arn,)
+        flow_arn, status = self.mediaconnect_backend.start_flow(flow_arn=flow_arn)
         return json.dumps(dict(flowArn=flow_arn, status=status))
 
     def stop_flow(self):
         flow_arn = unquote(self._get_param("flowArn"))
-        flow_arn, status = self.mediaconnect_backend.stop_flow(flow_arn=flow_arn,)
+        flow_arn, status = self.mediaconnect_backend.stop_flow(flow_arn=flow_arn)
         return json.dumps(dict(flowArn=flow_arn, status=status))
 
     def tag_resource(self):
         resource_arn = unquote(self._get_param("resourceArn"))
         tags = self._get_param("tags")
-        self.mediaconnect_backend.tag_resource(
-            resource_arn=resource_arn, tags=tags,
-        )
+        self.mediaconnect_backend.tag_resource(resource_arn=resource_arn, tags=tags)
         return json.dumps(dict())
 
     def list_tags_for_resource(self):
         resource_arn = unquote(self._get_param("resourceArn"))
         tags = self.mediaconnect_backend.list_tags_for_resource(
-            resource_arn=resource_arn,
+            resource_arn=resource_arn
         )
         return json.dumps(dict(tags=tags))
 
@@ -118,5 +114,3 @@ class MediaConnectResponse(BaseResponse):
             flow_arn=flow_arn, output_name=output_name
         )
         return json.dumps(dict(flow_arn=flow_arn, output_name=output_name))
-
-    # add methods from here
