@@ -2,7 +2,6 @@ import json
 import os
 from datetime import datetime
 from moto.core import ACCOUNT_ID, BaseBackend, BaseModel, CloudFormationModel
-from moto.core.exceptions import RESTError
 from moto.core.utils import BackendDict
 from moto.sagemaker import validators
 from moto.utilities.paginator import paginate
@@ -36,6 +35,13 @@ PAGINATION_MODEL = {
         "unique_attribute": "trial_component_arn",
         "fail_on_invalid_token": True,
     },
+    "list_tags": {
+        "input_token": "NextToken",
+        "limit_key": "MaxResults",
+        "limit_default": 50,
+        "unique_attribute": "Key",
+        "fail_on_invalid_token": True,
+    },
 }
 
 
@@ -74,9 +80,9 @@ class FakeProcessingJob(BaseObject):
         processing_inputs,
         processing_job_name,
         processing_output_config,
-        processing_resources,
         region_name,
         role_arn,
+        tags,
         stopping_condition,
     ):
         self.processing_job_name = processing_job_name
@@ -88,7 +94,7 @@ class FakeProcessingJob(BaseObject):
         self.creation_time = now_string
         self.last_modified_time = now_string
         self.processing_end_time = now_string
-
+        self.tags = tags or []
         self.role_arn = role_arn
         self.app_specification = app_specification
         self.experiment_config = experiment_config
@@ -153,7 +159,7 @@ class FakeTrainingJob(BaseObject):
         self.resource_config = resource_config
         self.vpc_config = vpc_config
         self.stopping_condition = stopping_condition
-        self.tags = tags
+        self.tags = tags or []
         self.enable_network_isolation = enable_network_isolation
         self.enable_inter_container_traffic_encryption = (
             enable_inter_container_traffic_encryption
@@ -279,8 +285,8 @@ class FakeEndpoint(BaseObject, CloudFormationModel):
         return self.endpoint_arn
 
     @classmethod
-    def has_cfn_attr(cls, attribute):
-        return attribute in ["EndpointName"]
+    def has_cfn_attr(cls, attr):
+        return attr in ["EndpointName"]
 
     def get_cfn_attribute(self, attribute_name):
         # https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-sagemaker-endpoint.html#aws-resource-sagemaker-endpoint-return-values
@@ -318,7 +324,7 @@ class FakeEndpoint(BaseObject, CloudFormationModel):
 
     @classmethod
     def update_from_cloudformation_json(
-        cls, original_resource, new_resource_name, cloudformation_json, region_name,
+        cls, original_resource, new_resource_name, cloudformation_json, region_name
     ):
         # Changes to the Endpoint will not change resource name
         cls.delete_from_cloudformation_json(
@@ -469,8 +475,8 @@ class FakeEndpointConfig(BaseObject, CloudFormationModel):
         return self.endpoint_config_arn
 
     @classmethod
-    def has_cfn_attr(cls, attribute):
-        return attribute in ["EndpointConfigName"]
+    def has_cfn_attr(cls, attr):
+        return attr in ["EndpointConfigName"]
 
     def get_cfn_attribute(self, attribute_name):
         # https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-sagemaker-endpointconfig.html#aws-resource-sagemaker-endpointconfig-return-values
@@ -510,7 +516,7 @@ class FakeEndpointConfig(BaseObject, CloudFormationModel):
 
     @classmethod
     def update_from_cloudformation_json(
-        cls, original_resource, new_resource_name, cloudformation_json, region_name,
+        cls, original_resource, new_resource_name, cloudformation_json, region_name
     ):
         # Most changes to the endpoint config will change resource name for EndpointConfigs
         cls.delete_from_cloudformation_json(
@@ -581,8 +587,8 @@ class Model(BaseObject, CloudFormationModel):
         return self.model_arn
 
     @classmethod
-    def has_cfn_attr(cls, attribute):
-        return attribute in ["ModelName"]
+    def has_cfn_attr(cls, attr):
+        return attr in ["ModelName"]
 
     def get_cfn_attribute(self, attribute_name):
         # https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-sagemaker-model.html#aws-resource-sagemaker-model-return-values
@@ -624,7 +630,7 @@ class Model(BaseObject, CloudFormationModel):
 
     @classmethod
     def update_from_cloudformation_json(
-        cls, original_resource, new_resource_name, cloudformation_json, region_name,
+        cls, original_resource, new_resource_name, cloudformation_json, region_name
     ):
         # Most changes to the model will change resource name for Models
         cls.delete_from_cloudformation_json(
@@ -801,8 +807,8 @@ class FakeSagemakerNotebookInstance(CloudFormationModel):
         return self.arn
 
     @classmethod
-    def has_cfn_attr(cls, attribute):
-        return attribute in ["NotebookInstanceName"]
+    def has_cfn_attr(cls, attr):
+        return attr in ["NotebookInstanceName"]
 
     def get_cfn_attribute(self, attribute_name):
         # https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-sagemaker-notebookinstance.html#aws-resource-sagemaker-notebookinstance-return-values
@@ -839,7 +845,7 @@ class FakeSagemakerNotebookInstance(CloudFormationModel):
 
     @classmethod
     def update_from_cloudformation_json(
-        cls, original_resource, new_resource_name, cloudformation_json, region_name,
+        cls, original_resource, new_resource_name, cloudformation_json, region_name
     ):
         # Operations keep same resource name so delete old and create new to mimic update
         cls.delete_from_cloudformation_json(
@@ -877,8 +883,10 @@ class FakeSageMakerNotebookInstanceLifecycleConfig(BaseObject, CloudFormationMod
         self.creation_time = self.last_modified_time = datetime.now().strftime(
             "%Y-%m-%d %H:%M:%S"
         )
-        self.notebook_instance_lifecycle_config_arn = FakeSageMakerNotebookInstanceLifecycleConfig.arn_formatter(
-            self.notebook_instance_lifecycle_config_name, self.region_name
+        self.notebook_instance_lifecycle_config_arn = (
+            FakeSageMakerNotebookInstanceLifecycleConfig.arn_formatter(
+                self.notebook_instance_lifecycle_config_name, self.region_name
+            )
         )
 
     @staticmethod
@@ -908,8 +916,8 @@ class FakeSageMakerNotebookInstanceLifecycleConfig(BaseObject, CloudFormationMod
         return self.notebook_instance_lifecycle_config_arn
 
     @classmethod
-    def has_cfn_attr(cls, attribute):
-        return attribute in ["NotebookInstanceLifecycleConfigName"]
+    def has_cfn_attr(cls, attr):
+        return attr in ["NotebookInstanceLifecycleConfigName"]
 
     def get_cfn_attribute(self, attribute_name):
         # https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-sagemaker-notebookinstancelifecycleconfig.html#aws-resource-sagemaker-notebookinstancelifecycleconfig-return-values
@@ -945,7 +953,7 @@ class FakeSageMakerNotebookInstanceLifecycleConfig(BaseObject, CloudFormationMod
 
     @classmethod
     def update_from_cloudformation_json(
-        cls, original_resource, new_resource_name, cloudformation_json, region_name,
+        cls, original_resource, new_resource_name, cloudformation_json, region_name
     ):
         # Operations keep same resource name so delete old and create new to mimic update
         cls.delete_from_cloudformation_json(
@@ -1094,51 +1102,38 @@ class SageMakerModelBackend(BaseBackend):
             "LastModifiedTime": experiment_data.last_modified_time,
         }
 
-    def add_tags_to_experiment(self, experiment_arn, tags):
-        experiment = [
-            self.experiments[i]
-            for i in self.experiments
-            if self.experiments[i].experiment_arn == experiment_arn
-        ][0]
-        experiment.tags.extend(tags)
+    def _get_resource_from_arn(self, arn):
+        resources = {
+            "model": self._models,
+            "notebook-instance": self.notebook_instances,
+            "endpoint": self.endpoints,
+            "endpoint-config": self.endpoint_configs,
+            "training-job": self.training_jobs,
+            "experiment": self.experiments,
+            "experiment-trial": self.trials,
+            "experiment-trial-component": self.trial_components,
+            "processing-job": self.processing_jobs,
+        }
+        target_resource, target_name = arn.split(":")[-1].split("/")
+        try:
+            resource = resources.get(target_resource).get(target_name)
+        except KeyError:
+            message = f"Could not find {target_resource} with name {target_name}"
+            raise ValidationError(message=message)
+        return resource
 
-    def add_tags_to_trial(self, trial_arn, tags):
-        trial = [
-            self.trials[i] for i in self.trials if self.trials[i].trial_arn == trial_arn
-        ][0]
-        trial.tags.extend(tags)
+    def add_tags(self, arn, tags):
+        resource = self._get_resource_from_arn(arn)
+        resource.tags.extend(tags)
 
-    def add_tags_to_trial_component(self, trial_component_arn, tags):
-        trial_component = [
-            self.trial_components[i]
-            for i in self.trial_components
-            if self.trial_components[i].trial_component_arn == trial_component_arn
-        ][0]
-        trial_component.tags.extend(tags)
+    @paginate(pagination_model=PAGINATION_MODEL)
+    def list_tags(self, arn):
+        resource = self._get_resource_from_arn(arn)
+        return resource.tags
 
-    def delete_tags_from_experiment(self, experiment_arn, tag_keys):
-        experiment = [
-            self.experiments[i]
-            for i in self.experiments
-            if self.experiments[i].experiment_arn == experiment_arn
-        ][0]
-        experiment.tags = [tag for tag in experiment.tags if tag["Key"] not in tag_keys]
-
-    def delete_tags_from_trial(self, trial_arn, tag_keys):
-        trial = [
-            self.trials[i] for i in self.trials if self.trials[i].trial_arn == trial_arn
-        ][0]
-        trial.tags = [tag for tag in trial.tags if tag["Key"] not in tag_keys]
-
-    def delete_tags_from_trial_component(self, trial_component_arn, tag_keys):
-        trial_component = [
-            self.trial_components[i]
-            for i in self.trial_components
-            if self.trial_components[i].trial_component_arn == trial_component_arn
-        ][0]
-        trial_component.tags = [
-            tag for tag in trial_component.tags if tag["Key"] not in tag_keys
-        ]
+    def delete_tags(self, arn, tag_keys):
+        resource = self._get_resource_from_arn(arn)
+        resource.tags = [tag for tag in resource.tags if tag["Key"] not in tag_keys]
 
     @paginate(pagination_model=PAGINATION_MODEL)
     def list_experiments(self):
@@ -1280,27 +1275,7 @@ class SageMakerModelBackend(BaseBackend):
             )
             raise ValidationError(message=message)
 
-    def get_experiment_by_arn(self, arn):
-        experiments = [
-            experiment
-            for experiment in self.experiments.values()
-            if experiment.experiment_arn == arn
-        ]
-        if len(experiments) == 0:
-            message = "RecordNotFound"
-            raise ValidationError(message=message)
-        return experiments[0]
-
-    def get_experiment_tags(self, arn):
-        try:
-            experiment = self.get_experiment_by_arn(arn)
-            return experiment.tags or []
-        except RESTError:
-            return []
-
-    def create_trial(
-        self, trial_name, experiment_name,
-    ):
+    def create_trial(self, trial_name, experiment_name):
         trial = FakeTrial(
             region_name=self.region_name,
             trial_name=trial_name,
@@ -1329,20 +1304,6 @@ class SageMakerModelBackend(BaseBackend):
             )
             raise ValidationError(message=message)
 
-    def get_trial_by_arn(self, arn):
-        trials = [trial for trial in self.trials.values() if trial.trial_arn == arn]
-        if len(trials) == 0:
-            message = "RecordNotFound"
-            raise ValidationError(message=message)
-        return trials[0]
-
-    def get_trial_tags(self, arn):
-        try:
-            trial = self.get_trial_by_arn(arn)
-            return trial.tags or []
-        except RESTError:
-            return []
-
     @paginate(pagination_model=PAGINATION_MODEL)
     def list_trials(self, experiment_name=None, trial_component_name=None):
         trials_fetched = list(self.trials.values())
@@ -1364,9 +1325,7 @@ class SageMakerModelBackend(BaseBackend):
             if evaluate_filter_expression(trial_data)
         ]
 
-    def create_trial_component(
-        self, trial_component_name, trial_name,
-    ):
+    def create_trial_component(self, trial_component_name, trial_name):
         trial_component = FakeTrialComponent(
             region_name=self.region_name,
             trial_component_name=trial_component_name,
@@ -1385,24 +1344,6 @@ class SageMakerModelBackend(BaseBackend):
             )
             raise ValidationError(message=message)
 
-    def get_trial_component_by_arn(self, arn):
-        trial_components = [
-            trial_component
-            for trial_component in self.trial_components.values()
-            if trial_component.trial_component_arn == arn
-        ]
-        if len(trial_components) == 0:
-            message = "RecordNotFound"
-            raise ValidationError(message=message)
-        return trial_components[0]
-
-    def get_trial_component_tags(self, arn):
-        try:
-            trial_component = self.get_trial_component_by_arn(arn)
-            return trial_component.tags or []
-        except RESTError:
-            return []
-
     def describe_trial_component(self, trial_component_name):
         try:
             return self.trial_components[trial_component_name].response_object
@@ -1521,16 +1462,6 @@ class SageMakerModelBackend(BaseBackend):
         except KeyError:
             raise ValidationError(message="RecordNotFound")
 
-    def get_notebook_instance_by_arn(self, arn):
-        instances = [
-            notebook_instance
-            for notebook_instance in self.notebook_instances.values()
-            if notebook_instance.arn == arn
-        ]
-        if len(instances) == 0:
-            raise ValidationError(message="RecordNotFound")
-        return instances[0]
-
     def start_notebook_instance(self, notebook_instance_name):
         notebook_instance = self.get_notebook_instance(notebook_instance_name)
         notebook_instance.start()
@@ -1548,13 +1479,6 @@ class SageMakerModelBackend(BaseBackend):
             raise ValidationError(message=message)
         del self.notebook_instances[notebook_instance_name]
 
-    def get_notebook_instance_tags(self, arn):
-        try:
-            notebook_instance = self.get_notebook_instance_by_arn(arn)
-            return notebook_instance.tags or []
-        except RESTError:
-            return []
-
     def create_notebook_instance_lifecycle_config(
         self, notebook_instance_lifecycle_config_name, on_create, on_start
     ):
@@ -1658,9 +1582,7 @@ class SageMakerModelBackend(BaseBackend):
             )
             raise ValidationError(message=message)
 
-    def create_endpoint(
-        self, endpoint_name, endpoint_config_name, tags,
-    ):
+    def create_endpoint(self, endpoint_name, endpoint_config_name, tags):
         try:
             endpoint_config = self.describe_endpoint_config(endpoint_config_name)
         except KeyError:
@@ -1699,24 +1621,6 @@ class SageMakerModelBackend(BaseBackend):
             )
             raise ValidationError(message=message)
 
-    def get_endpoint_by_arn(self, arn):
-        endpoints = [
-            endpoint
-            for endpoint in self.endpoints.values()
-            if endpoint.endpoint_arn == arn
-        ]
-        if len(endpoints) == 0:
-            message = "RecordNotFound"
-            raise ValidationError(message=message)
-        return endpoints[0]
-
-    def get_endpoint_tags(self, arn):
-        try:
-            endpoint = self.get_endpoint_by_arn(arn)
-            return endpoint.tags or []
-        except RESTError:
-            return []
-
     def create_processing_job(
         self,
         app_specification,
@@ -1725,8 +1629,8 @@ class SageMakerModelBackend(BaseBackend):
         processing_inputs,
         processing_job_name,
         processing_output_config,
-        processing_resources,
         role_arn,
+        tags,
         stopping_condition,
     ):
         processing_job = FakeProcessingJob(
@@ -1736,10 +1640,10 @@ class SageMakerModelBackend(BaseBackend):
             processing_inputs=processing_inputs,
             processing_job_name=processing_job_name,
             processing_output_config=processing_output_config,
-            processing_resources=processing_resources,
             region_name=self.region_name,
             role_arn=role_arn,
             stopping_condition=stopping_condition,
+            tags=tags,
         )
         self.processing_jobs[processing_job_name] = processing_job
         return processing_job
@@ -1763,8 +1667,6 @@ class SageMakerModelBackend(BaseBackend):
         last_modified_time_before,
         name_contains,
         status_equals,
-        sort_by,
-        sort_order,
     ):
         if next_token:
             try:
@@ -1903,23 +1805,6 @@ class SageMakerModelBackend(BaseBackend):
             )
             raise ValidationError(message=message)
 
-    def get_training_job_by_arn(self, arn):
-        training_jobs = [
-            training_job
-            for training_job in self.training_jobs.values()
-            if training_job.training_job_arn == arn
-        ]
-        if len(training_jobs) == 0:
-            raise ValidationError(message="RecordNotFound")
-        return training_jobs[0]
-
-    def get_training_job_tags(self, arn):
-        try:
-            training_job = self.get_training_job_by_arn(arn)
-            return training_job.tags or []
-        except RESTError:
-            return []
-
     def _update_training_job_details(self, training_job_name, details_json):
         self.training_jobs[training_job_name].update(details_json)
 
@@ -1933,8 +1818,6 @@ class SageMakerModelBackend(BaseBackend):
         last_modified_time_before,
         name_contains,
         status_equals,
-        sort_by,
-        sort_order,
     ):
         if next_token:
             try:
@@ -2009,9 +1892,7 @@ class SageMakerModelBackend(BaseBackend):
 
 
 class FakeExperiment(BaseObject):
-    def __init__(
-        self, region_name, experiment_name, tags,
-    ):
+    def __init__(self, region_name, experiment_name, tags):
         self.experiment_name = experiment_name
         self.experiment_arn = FakeExperiment.arn_formatter(experiment_name, region_name)
         self.tags = tags
@@ -2044,7 +1925,7 @@ class FakeExperiment(BaseObject):
 
 class FakeTrial(BaseObject):
     def __init__(
-        self, region_name, trial_name, experiment_name, tags, trial_components,
+        self, region_name, trial_name, experiment_name, tags, trial_components
     ):
         self.trial_name = trial_name
         self.trial_arn = FakeTrial.arn_formatter(trial_name, region_name)
@@ -2079,9 +1960,7 @@ class FakeTrial(BaseObject):
 
 
 class FakeTrialComponent(BaseObject):
-    def __init__(
-        self, region_name, trial_component_name, trial_name, tags,
-    ):
+    def __init__(self, region_name, trial_component_name, trial_name, tags):
         self.trial_component_name = trial_component_name
         self.trial_component_arn = FakeTrialComponent.arn_formatter(
             trial_component_name, region_name
