@@ -156,15 +156,10 @@ class SWFResponse(BaseResponse):
 
         workflow_executions = self.swf_backend.list_closed_workflow_executions(
             domain_name=domain,
-            start_time_filter=start_time_filter,
-            close_time_filter=close_time_filter,
-            execution_filter=execution_filter,
             tag_filter=tag_filter,
-            type_filter=type_filter,
+            close_status_filter=close_status_filter,
             maximum_page_size=maximum_page_size,
             reverse_order=reverse_order,
-            workflow_id=workflow_id,
-            close_status_filter=close_status_filter,
         )
 
         return json.dumps(
@@ -200,13 +195,9 @@ class SWFResponse(BaseResponse):
 
         workflow_executions = self.swf_backend.list_open_workflow_executions(
             domain_name=domain,
-            start_time_filter=start_time_filter,
-            execution_filter=execution_filter,
-            tag_filter=tag_filter,
-            type_filter=type_filter,
             maximum_page_size=maximum_page_size,
+            tag_filter=tag_filter,
             reverse_order=reverse_order,
-            workflow_id=workflow_id,
         )
 
         return json.dumps(
